.. toctree::
    :caption: Administrator docs
    :maxdepth: 1

    admin/quick
    admin/install
    admin/deployments
    admin/upgrade
    admin/backup
    admin/auth
    admin/access
    admin/projects
    admin/languages
    admin/continuous
    admin/licensing
    admin/translating
    admin/checks
    admin/machine
    admin/addons
    admin/memory
    admin/config
    admin/sample
    admin/management
    admin/whiteboard
    admin/componentlists
    admin/optionals
    admin/customize
    admin/admin
    admin/support
